import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max, format, extent, scaleTime, scaleOrdinal, timeFormat } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { tooltipContext } from "./Tooltip";


const width = 960;
const height = 500;
const margin = {top: 50, right:50, bottom:70, left: 100};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 50;
const tickOffset = 5;
const circleRadius = 3;


const App = () => {
  
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
    
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  
	const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
 
	const yValue = d => d.temperature;
  const yAxisLabel = 'Temp';

  
	// const siFormat = formatDate('.2s');
  const xAxisTickFormat = timeFormat("%a")
  
  const xScale = scaleTime()
  .domain(extent(data, xValue))
    .range([0, innerWidth])
  
  const yScale = scaleLinear()
  .domain(extent(data, yValue))
    .range([innerHeight, 0])
  
  console.log("X Scale Ticks:", xScale.ticks(5));
    console.log("Y Scale Ticks:", yScale.domain());
  
  const Tooltip = d3.select("#div_customContent")
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom 
          xScale={xScale} 
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={tickOffset}
          />
        <text 
          className="axis-label" 
          x={innerWidth / 2} 
          y={innerHeight + xAxisLabelOffset} 
          textAnchor="middle">
          {xAxisLabel}
        </text>
        <AxisLeft 
          yScale={yScale} 
          innerWidth={innerWidth} 
          />
        <text 
          className="axis-label" 
          textAnchor="middle"
          transform={` translate(${-yAxisLabelOffset},${innerHeight / 2}),rotate(-90)`}
          >
          {yAxisLabel}
        </text>
        <Marks 
          data={data} 
          xScale={xScale} 
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={circleRadius}
          />
      </g>
    </svg>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);